-- SQL Consolidated database with SQL Anywhere remote using TCPIP in High Availability   
-- SQL Anywhere Studio MobiLink Synchronization 10.0.1
-- Written by Joshua Savill
-- Product Manager - Sybase iAnywhere
-- January 22, 2008


/*------------------------------------------------------------------------------
*                           Set some Database Options.
*-----------------------------------------------------------------------------*/

set option public.Global_database_id = 678912345;
set option public.delete_old_logs = 'ON';

COMMIT;

/*------------------------------------------------------------------------------
*                           Create table 'DBA.Admin'.
*-----------------------------------------------------------------------------*/

CREATE TABLE "DBA"."Admin"     (
	"admin_id" bigint default global autoincrement primary key,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                           Create table 'DBA.Child'.
*-----------------------------------------------------------------------------*/

CREATE TABLE "DBA"."Child"     (
	"child_id" bigint default global autoincrement primary key,
	"parent_id" bigint null,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                         Create table 'DBA.Inventory'.
*-----------------------------------------------------------------------------*/

CREATE TABLE "DBA"."Inventory"     (
	"inventory_id" bigint default global autoincrement primary key,
	"data" integer null
);

COMMIT;
/*------------------------------------------------------------------------------
*                          Create table 'DBA.Parent'.
*-----------------------------------------------------------------------------*/

CREATE TABLE "DBA"."Parent"     (
	"parent_id" bigint default global autoincrement primary key,
	"user_id" varchar(128) null,
	"data" varchar(30) null
);

COMMIT;
/*------------------------------------------------------------------------------
*                          Procedures to add test data.
*-----------------------------------------------------------------------------*/

create procedure DBA.rep_data(in iter integer default 1,in do_commit integer default 0)
begin
  declare loop_var integer;
  
  set loop_var=0;
  while loop_var < iter loop
    insert into Admin(data) values(cast(RAND(*)*20+1 as char(10)));
    insert into Parent(user_id,data) values('rem500',cast(RAND(*)*20+1 as char(10)));
    insert into Child(parent_id,data) values(@@identity,cast(RAND(*)*20+1 as char(10)));
    set loop_var=loop_var+1;
    if do_commit = 1 then
      commit;
    end if
  end loop;
end;

create procedure DBA.rep_data_inventory(in iter integer default 1,in do_commit integer default 0)
begin
  declare loop_var integer;
  
  set loop_var=0;
  while loop_var < iter loop
    insert into Inventory(data) values(loop_var);
    set loop_var=loop_var+1;
    if do_commit = 1 then
      commit;
    end if
  end loop;
end;

/*------------------------------------------------------------------------------
*                           Create publication 'pub1'.
*-----------------------------------------------------------------------------*/
CREATE PUBLICATION "pub1" (
		TABLE "DBA"."Admin",
		TABLE "DBA"."Child",
		TABLE "DBA"."Inventory",
		TABLE "DBA"."Parent"
);

/*------------------------------------------------------------------------------
*                          Create the user 'rem500'.
*-----------------------------------------------------------------------------*/
CREATE SYNCHRONIZATION USER "rem600";

/*------------------------------------------------------------------------------
*                  Create subscription to 'pub1' for 'ml_user'.
*-----------------------------------------------------------------------------*/
CREATE SYNCHRONIZATION SUBSCRIPTION TO "pub1" FOR "rem600"
		OPTIONS ScriptVersion='https_v1';

/*------------------------------------------------------------------------------
*                  Create a synchronization event to start
*		   MobiLink synchronization
*-----------------------------------------------------------------------------*/

CREATE EVENT SyncEvent
SCHEDULE daily_sync
BETWEEN '5:00AM' AND '11:00PM'
EVERY 1 MINUTES
HANDLER
  BEGIN
    MESSAGE 'Synchronization Triggered';
    IF CAST( EVENT_PARAMETER( 'NumActive' ) AS INTEGER ) > 1 THEN RETURN;
    END IF;
    CALL xp_cmdshell( 'dbisql -c "DSN=tcpip_rem6" insert2.sql', 'no_output' );
    CALL xp_cmdshell( 'dbisql -c "DSN=tcpip_cons" insert2.sql', 'no_output' );
    CALL xp_cmdshell( 'dbmlsync -k -c "DSN=tcpip_rem6" -mp sql -v+ -o rem.txt -e "scn=on;ctp=tcpip;adr=''timeout=1000;host=localhost;port=2439''"', 'no_output' );  
  END;

COMMIT;